about summary refs log tree commit diff
path: root/src/test/bench/std-smallintmap.rs
diff options
context:
space:
mode:
authorDaniel Micay <danielmicay@gmail.com>2013-01-31 18:18:07 -0500
committerDaniel Micay <danielmicay@gmail.com>2013-01-31 23:13:56 -0500
commit70855f5a07bb17e6690c32832dec452cb211b18a (patch)
treeb9bffafcba4e94f4dc530c88f625fb8cf3bf19b4 /src/test/bench/std-smallintmap.rs
parent9ba7114515db355ca36065d2730e3ee6c84cd6d1 (diff)
downloadrust-70855f5a07bb17e6690c32832dec452cb211b18a.tar.gz
rust-70855f5a07bb17e6690c32832dec452cb211b18a.zip
move smallintmap to oldsmallintmap
Diffstat (limited to 'src/test/bench/std-smallintmap.rs')
-rw-r--r--src/test/bench/std-smallintmap.rs8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/test/bench/std-smallintmap.rs b/src/test/bench/std-smallintmap.rs
index a72831c2b06..60efb14e2dc 100644
--- a/src/test/bench/std-smallintmap.rs
+++ b/src/test/bench/std-smallintmap.rs
@@ -8,11 +8,11 @@
 // option. This file may not be copied, modified, or distributed
 // except according to those terms.
 
 // Microbenchmark for the smallintmap library
 
 extern mod std;
-use std::smallintmap;
-use std::smallintmap::SmallIntMap;
+use std::oldsmallintmap;
+use std::oldsmallintmap::SmallIntMap;
 use io::WriterUtil;
 
 fn append_sequential(min: uint, max: uint, map: SmallIntMap<uint>) {
@@ -43,7 +43,7 @@ fn main() {
     let mut appendf = 0.0;
 
     for uint::range(0u, rep) |_r| {
-        let map = smallintmap::mk();
+        let map = oldsmallintmap::mk();
         let start = std::time::precise_time_s();
         append_sequential(0u, max, map);
         let mid = std::time::precise_time_s();
@@ -8,11 +8,11 @@
 // except according to those terms.
 
-// Microbenchmark for the smallintmap library
+// Microbenchmark for the oldsmallintmap library
 
 extern mod std;